@@ -219,31 +219,11 @@ use 5.006;
 use strict;
 use warnings;
 use bytes;
+
+our $VERSION = '1.16';
+
 use Cache::FastMmap::CImpl;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
-
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use Cache::FastMmap ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(
-	
-) ] );
-
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-our @EXPORT = qw(
-	
-);
-
-our $VERSION = '1.15';
-
 use constant FC_ISDIRTY => 1;
 # }}}
 
